function [ gradient ] = adversarialRegularizer( cnet, input, target, ...
    targetWeights, dldx, gradient  )
%ADVERSARIALREGULARIZER Do a second gradient pass with an adversarial
% example of the input.
% Author: Benedikt Staffler <benedikt.staffler@brain.mpg.de>

[ activity, dropoutMask, mpInd, bn ] = forwardPass( cnet, ...
    input + cnet.adversarialEps.*sign(dldx) );
gradient_ad = backprop( cnet, activity, dropoutMask, mpInd, bn, ...
    target, targetWeights );
a = cnet.adversarialLambda;
gradient.W(2:end) = cellfun(@(x, y) (1 - a).*x + a.*y, ...
    gradient.W(2:end), gradient_ad.W(2:end), 'uni', 0);
gradient.b(2:end) = cellfun(@(x, y) (1 - a).*x + a.*y, ...
    gradient.b(2:end), gradient_ad.b(2:end), 'uni', 0);
gradient.beta(2:end) = cellfun(@(x, y) (1 - a).*x + a.*y, ...
    gradient.beta(2:end), gradient_ad.beta(2:end), 'uni', 0);
gradient.gamma(2:end) = cellfun(@(x, y) (1 - a).*x + a.*y, ...
    gradient.gamma(2:end), gradient_ad.gamma(2:end), 'uni', 0);
end

