classdef CNNFeat < SynEM.Feature.TextureFeature
    %CNNFEAT Features generated by a Codat.CNN
    % PROPERTIES
    %  cnn: Codat.CNN.cnn object.
    %       CNN used for feature calculation.
    %  options: struct
    %       see Codat.CNN.Misc.predictCube
    % Author: Benedikt Staffler <benedikt.staffler@brain.mpg.de>

    properties
        cnn
        options = struct();
        fRawNorm = [];
        doPad = true;
    end

    methods
        function obj = CNNFeat(cnn, options, fRawNorm)
            obj.name = 'CNN';
            obj.cnn = cnn;
            obj.border = cnn.border;

            if exist('options', 'var') && ~isempty(options)
                obj.options = options;
            end

            if ~isfield(obj.options, 'fmL')
                %use output layer as default
                obj.options.fmL = cnn.layer;
            end
            if ~isfield(obj.options, 'fmL_idx') || isempty(options.fmL_idx)
                obj.options.fmL_idx = [];
                obj.numChannels = sum(cnn.featureMaps(obj.options.fmL));
            else
                obj.numChannels = sum(cellfun(@length, ...
                    obj.options.fmL_idx));
            end


            if exist('fRawNorm', 'var') && ~isempty(fRawNorm)
                if ~ischar(fRawNorm)
                    fRawNorm = func2str(fRawNorm);
                end
                obj.fRawNorm = fRawNorm;
            end
        end

        function fm = calc(obj, raw)
            if ~isempty(obj.fRawNorm)
                f = str2func(obj.fRawNorm);
                raw = f(raw);
            end
            if obj.doPad %mainly fix for training data
                raw = padarray(raw, obj.border./2, 'symmetric', 'both');
            end
            fm = Codat.CNN.Misc.predictCube(obj.cnn, raw, obj.options);
            if obj.numChannels > 1
                tmp = cell(size(fm, 4), 1);
                % hack to avoid duplication of memory (avoids out of
                % memory error in some cases)
                for i = 1:size(fm, 4)
                    tmp{i} = fm(:,:,:,1);
                    fm = fm(:,:,:,2:end);
                end
                fm = tmp;
%                 fm = squeeze(num2cell(fm, 1:3));
            end
        end

        function obj = useDevice(obj, dev)
            switch dev
                case 'cpu'
                    obj.options.gpuDev = false;
                case 'gpu'
                    obj.options.gpuDev = true;
                otherwise
                    obj.options.gpuDev = false;
            end
        end
    end

end
