function [ y, scores ] = predict( classificationStruct, X, varargin )
%PREDICT Use the output of getPredictionVariables to for classification.
% This function produces equivalent outputs to the standard predict
% function of a matlab ensemble but much faster.
% INPUT classificationStruct: Struct generated by getPredictionVariables
%       X: Input data (rows correspond to variables, colums to features)
%       varargin: The indices of the learners to use (e.g. 1:10 for the
%                 first 10 weak learners).
% OUTPUT y: As for standard predict function.
%        scores: The first column of scores of the standard predict
%                function (the second column equals -scores).
% Author: Benedikt Staffler <benedikt.staffler@brain.mpg.de>

if ~isempty(varargin)
    learners = varargin{1};
else
    learners = 1:length(classificationStruct.W);
end

W = classificationStruct.W;
cutVars = classificationStruct.cutVars;
cutPoints = classificationStruct.cutPoints;
leftNodePred = classificationStruct.leftNodePred;
rightNodePred = classificationStruct.rightNodePred;

scores = zeros(size(X,1),1);
for i = learners
    indices = X(:,cutVars(i)) < cutPoints(i);
    scores = scores + W(i).*((indices.*leftNodePred(i) + ~indices.*rightNodePred(i)));
end
y = scores > 0;


end

