function script = buildJobScript( ...
    jobID, jobName, numTasks, ...
    submitArgs, envVars, taskLocs, taskLogs)
% Written by
%   Alessandro Motta
q = '''';

parts = {};
parts{end + 1} = [ ...
    '#!/bin/bash\n', ...
    '#$ -S /bin/bash\n', ...
    '#$ -N ', q, jobName, q, '\n', ...
    '#$ -o /dev/null\n', ...
    '#$ -e /dev/null\n', ...
    '#$ -t 1-', num2str(numTasks), '\n'];

parts{end + 1} = [ ...
    '\n', ...
    '# setting additional SGE parameters\n'];

% use submitted arguments
for argIdx = 1:length(submitArgs)
    argVal = submitArgs{argIdx};
    parts{end + 1} = ['#$ ', argVal, '\n'];
end

parts{end + 1} = [ ...
    '\n', ...
    '# job specific environment variables\n'];

% set environment variables
for varIdx = 1:size(envVars, 1)
    varName = envVars{varIdx, 1};
    varVal = envVars{varIdx, 2};
    parts{end + 1} = [ ...
        'export ', varName, '=', q, varVal, q, '\n'];
end

% redirect stdout
parts{end + 1} = [ ...
    '\n', ...
    '# closing standard out and error\n', ...
    'exec 1<&-\n', ...
    'exec 2<&-\n'];

% set task specific stuff
parts{end + 1} = [
    '\n', ...
    '# setting up task specific stuff\n', ...
    'case $SGE_TASK_ID in\n'];

for taskIdx = 1:numTasks
    taskLoc = taskLocs{taskIdx};
    taskLog = taskLogs{taskIdx};

    parts{end + 1} = [ ...
        '\t', num2str(taskIdx), ')\n', ...
        '\t\t', 'MDCE_TASK_LOCATION=', q, taskLoc, q, '\n', ...
        '\t\t', 'exec 1<>', q, taskLog, q, '\n', ...
        '\t\t', ';;\n'];
end

% end task specific stuff
parts{end + 1} = [
    '\t', '*)\n', ...
    '\t\t', 'echo "Error!"\n', ...
    'esac\n'];

% redirect stderr to stdout
parts{end + 1} = [ ...
    '\n', ...
    '# redirect standard error to output\n', ...
    'exec 2>&1\n'];

% export task location
parts{end + 1} = [ ...
    '\n', ...
    '# export task location\n', ...
    'export MDCE_TASK_LOCATION\n'];

% set working directory
parts{end + 1} = [ ...
    '\n', ...
    '# set working directory\n', ...
    'cd "${SGE_O_WORKDIR}"\n'];

% execute tasks
parts{end + 1} = [ ...
    '\n', ...
    '# Run main command\n', ...
    'echo "Executing: ${MDCE_MATLAB_EXE} ${MDCE_MATLAB_ARGS}"\n', ...
    'exec "${MDCE_MATLAB_EXE}" ${MDCE_MATLAB_ARGS}\n'];

% build script
script = strjoin(parts, '');

end
