function treeIdx = getTreeWithName( skel, name, mode, complement )
%Get all nodes with a name from a tree.
% INPUT name: cell Array, char string
%           String/strings to look for in the tree names.
%       mode: (Optional) string
%           Specify search mode
%           'exact': Exactly matches the name (Default)
%           'partial': name is partially contained in a node
%           	name.
%           'insensitive': Case-insensitive string matching
%           'regexp': regular expression matching
%       complement: (Optional) logical
%           set to true if you would like the complement set of treeIdx
% OUTPUT treeIdx: [Nx1] double
%           with the Tree ID's satisfying the name condiftion
% Author: Ali Karimi <ali.karimi@brain.mpg.de>
if ~exist('mode','var') || isempty(mode)
    mode = 'exact';
end

if ~exist('complement','var') || isempty(complement)
    complement = false;
end

if ~iscell(name)
    name={name};
end
% default to exact match
modeFun = @(x) strcmp(x, name);
treeIdx=[];

for i=1:length(name)
    switch mode
        case 'partial'
            modeFun = @(x) contains(x, name{i});
        case 'exact'
            modeFun = @(x) strcmp(x, name{i});
        case 'insensitive'
            modeFun = @(x) strcmpi(x, name{i});
        case 'regexp'
            modeFun = @(x) ~isempty(regexp(x, name{i}, 'once'));
        case 'first'
            modeFun=  @(x) strncmp(x,name{i},size(name{i},2));
        otherwise
            error('search mode for treename is incorrect');
    end
    
    curIdx = find(cellfun(modeFun,skel.names));
    treeIdx=[treeIdx;curIdx];
end
if complement
    treeIdx=setdiff(1:skel.numTrees,treeIdx);
end
end

